<?php
namespace Teknisa\EST\Modules\Relatorios\Controllers;

use Teknisa\EST\Controllers\TeknisaCrud;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DTO\Request\Filter;
use Zeedhi\Framework\DTO\Request\Row;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO;

class Est70000ResumoDeOperacoesController extends TeknisaCrud {

    protected $dataSourceName = "";
    protected $dataSourceManager;
    protected $environment;
    protected $service;
    protected $params = [];
    protected $hasMainGroup;
    
    public function __construct($crudService,$parameterBag, $dataSourceManager,$environment, $service) {
        parent::__construct($crudService,$parameterBag);

        $this->dataSourceManager = $dataSourceManager;
        $this->environment = $environment;
        $this->service = $service;
    }
    
    //This function gets all required data. it's the initial find
    public function find(DTO\Request\Filter $request, DTO\Response $response) {
        try{
            
            $conditions = $request->getFilterCriteria()->getConditions();
            
            //Sets params to make it easier to manage
            foreach($conditions as $conditions)
                $this->params[$conditions['columnName']] = $conditions['value'];
            
            //Verifies if it owns main group or groups by unity
            $groupsUnityInfo = $this->service->getGroupFiliInfo($this->params['CDGRUPPROD']);
            
            // Checks if it has main group to set the correct query
            foreach($groupsUnityInfo as $groupFili)
                $this->hasMainGroup = $groupFili['CDFILISUBGR'] == $this->params['CDFILIAL'] ? false : true ;
            
            // Gets Data to build final dataset
            $columns = $this->getDataSetColumns($request,$response);
            
            // it builds a final dataSet to return to frontend
            $dataSet = $this->service->dataSetBuilder($columns,$this->hasMainGroup,$this->params);
            
            $response->setDataSets([new DataSet("get_resumo_operacoes",$dataSet)]);
        }catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    // This function get all columns to display on frontend
    public function getDataSetColumns($request,$response){
        $filterCriteria = new FilterCriteria('subgrupprod', []);
    	$filterCriteria->addCondition('CDGRUPPROD', $this->params['CDGRUPPROD']);
    	$filterCriteria->addOrderBy('CDSUBGRPROD');
        $rows = $this->dataSourceManager->findBy($filterCriteria)->getRows();
        
        return $rows;
    }
}