<?php
namespace Folha\Entities;

use HCM\Util\DateUtil;
use Importacao\Logic\Integracao\ProjetoImportacao;

class MigAlteescala extends Base\MigAlteescala
{

    const DEFAULT_NRHORDIA = '';

    /**
     * @param $nralteescala
     * @return \Folha\Entities\MigAlteescala
     */
    public function setNralteescala ($nralteescala) {
        $nralteescala = \Importacao\Logic\Validacoes::verificaChaveDuplicada('GPE_ALTEESCALA', 'NRALTEESCALA', ProjetoImportacao::getNrorg(), $nralteescala);
        $this->nralteescala = $nralteescala;
    }

    /**
     * @param $nrvinculom
     * @return \Folha\Entities\MigAlteescala
     */
    public function setNrvinculom ($nrvinculom) {
        $nrvinculom = \Importacao\Logic\Validacoes::verificaChaveMae('GPE_VINCULOM', 'NRVINCULOM', ProjetoImportacao::getNrorg(), $nrvinculom);
        $this->nrvinculom = $nrvinculom;
    }

    /**
     * @param $nrescalatrabm
     * @throws \Exception
     * @return \Folha\Entities\MigAlteescala
     */
    public function setNrescalatrabm ($nrescalatrabm) {
        $nrorg = ProjetoImportacao::getNrorg();
        $escalatrab = \Folha\Entities\MigEscalatrabm::getObjectByWhere('NRESCALATRABM = ? AND NRORG = ?', array($nrescalatrabm, $nrorg));

        if (is_object($escalatrab)) {
            $this->nrescalatrabm = $nrescalatrabm;
        } else {
            throw new \Exception("O código da Escala de Trabalho '$nrescalatrabm' não foi encontrado.");
        }
    }

    /**
     * @param $nrhordiam
     * @return \Folha\Entities\MigAlteescala
     */
    public function setNrhordiam ($nrhordiam) {
        if (empty($nrhordiam)) {
            $nrhordiam = self::DEFAULT_NRHORDIA;
        }

        $this->nrhordiam = $nrhordiam;
    }

    /**
     * @param $dtiniescala
     * @throws \Exception
     * @return \Folha\Entities\MigAlteescala
     */
    public function setDtiniescala ($dtiniescala) {
        if (!preg_match("/\d{2}\/\d{2}\/\d{4}/", $dtiniescala)) {
            throw new \Exception("Campo Obrigatório - Início Escala: Data '$dtiniescala' com formato inválido ou em branco.");
        }

        if (!($dtiniescala instanceof \DateTime)) {
            $dtiniescala = DateUtil::getDataDeString($dtiniescala);
        }

        $this->dtiniescala = $dtiniescala;
    }

    /**
     * @param $dtfimescala
     * @throws \Exception
     * @return \Folha\Entities\MigAlteescala
     */
    public function setDtfimescala ($dtfimescala) {
        if (!preg_match("/\d{2}\/\d{2}\/\d{4}/", $dtfimescala)) {
            if (!empty($dtfimescala)) {
                throw new \Exception("Dt. Fim Escala: Data '$dtfimescala' com formato inválido ou em branco.");
            } else {
                throw new \Exception(null);
            }
        }

        if (!($dtfimescala instanceof \DateTime)) {
            $dtfimescala = DateUtil::getDataDeString($dtfimescala);
        }

        $this->dtfimescala = $dtfimescala;
    }

    /**
     * @param $dtultatu
     * @throws \Exception
     * @return \Folha\Entities\MigAlteescala
     */
    public function setDtultatu ($dtultatu) {
        if (!preg_match("/\d{2}\/\d{2}\/\d{4}/", $dtultatu)) {
            throw new \Exception("Data '$dtultatu' com formato inválido ou em branco.");
        }

        if (!($dtultatu instanceof \DateTime)) {
            $dtultatu = DateUtil::getDataDeString($dtultatu);
        }

        $this->dtultatu = $dtultatu;
    }

    /**
     * @param $dtinclusao
     * @throws \Exception
     * @return \Folha\Entities\MigAlteescala
     */
    public function setDtinclusao ($dtinclusao) {
        if (!preg_match("/\d{2}\/\d{2}\/\d{4}/", $dtinclusao)) {
            throw new \Exception("Data '$dtinclusao' com formato inválido ou em branco.");
        }

        if (!($dtinclusao instanceof \DateTime)) {
            $dtinclusao = DateUtil::getDataDeString($dtinclusao);
        }

        $this->dtinclusao = $dtinclusao;
    }

}